@@ -172,7 +172,7 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
 
                     if v[-1] == "\n":
                         v = v[:-1]
-                except (IndexError, KeyError):
+                except (IndexError, KeyError, TypeError):
                     # Catch scenarios where there is no data
                     pass
 
